Typed pointer event data for the wire protocol.
These structs represent the data payload of pointer and viewport events. They are shared between the SDK (which parses them from wire JSON) and could be used by the renderer to construct events with typed fields.
Structs
- KeyData
- Data from a widget-level key press or release event.
- Pointer
Boundary - Data from a pointer enter / exit event.
- Pointer
Drag - Data from a drag event.
- Pointer
Move - Data from a pointer move event.
- Pointer
Press - Data from a pointer press event (mouse button down, touch start).
- Pointer
Release - Data from a pointer release event (mouse button up, touch end).
- Pointer
Scroll - Data from a raw scroll input event (mouse wheel, trackpad).
- Resize
Dimensions - Data from a window or widget resize event.
- Scroll
Position - Viewport state from a scrollable widget’s “scrolled” event.