Module pointer

Module pointer 

Typed pointer event data for the wire protocol.

These structs represent the data payload of pointer and viewport events. They are shared between the SDK (which parses them from wire JSON) and could be used by the renderer to construct events with typed fields.

Structs

KeyData
Data from a widget-level key press or release event.
PointerBoundary
Data from a pointer enter / exit event.
PointerDrag
Data from a drag event.
PointerMove
Data from a pointer move event.
PointerPress
Data from a pointer press event (mouse button down, touch start).
PointerRelease
Data from a pointer release event (mouse button up, touch end).
PointerScroll
Data from a raw scroll input event (mouse wheel, trackpad).
ResizeDimensions
Data from a window or widget resize event.
ScrollPosition
Viewport state from a scrollable widget’s “scrolled” event.